@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/Dynamic.pm
-## Version v1.2.2
+## Version v1.2.3
 ## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/03/20
-## Modified 2022/11/12
+## Modified 2023/11/15
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -19,7 +19,7 @@ BEGIN
     use warnings::register;
     use Scalar::Util ();
     # use Class::ISA;
-    our $VERSION = 'v1.2.2';
+    our $VERSION = 'v1.2.3';
 };
 
 use strict;
@@ -218,7 +218,8 @@ sub AUTOLOAD
     else
     {
         my $ref = lc( ref( $_[0] ) );
-        my $handler = '_set_get_scalar_as_object';
+        # Default
+        my $handler = ( $ref eq 'scalar' || !$ref ) ? '_set_get_scalar_as_object' : '_set_get_scalar';
         # if( @_ && ( $ref eq 'hash' || $ref eq 'array' ) )
         if( $ref eq 'hash' || $ref eq 'array' )
         {
@@ -231,6 +232,10 @@ sub AUTOLOAD
         {
             $handler = '_set_get_boolean';
         }
+        elsif( $ref eq 'regexp' )
+        {
+            $handler = '_set_get_scalar';
+        }
         elsif( !$ref && $method =~ /(?<=[^a-zA-Z0-9])(date|datetime)(?!>[^a-zA-Z0-9])/ )
         {
             $handler = '_set_get_datetime';
