@@ -44,6 +44,9 @@ sub init
     return( $self );
 }
 
+# This class does not convert to an HASH
+sub as_hash { return( $_[0] ); }
+
 sub elements { return( shift->_set_get_array_as_object( 'elements', @_ ) ); }
 
 sub eof
@@ -228,6 +231,9 @@ sub init
     return( $self );
 }
 
+# This class does not convert to an HASH
+sub as_hash { return( $_[0] ); }
+
 sub has_next
 {
     my $self = shift( @_ );
